@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp qw/ croak /;
 
-our $VERSION = '0.0403.0';
+our $VERSION = '0.0300';
 
 our $COMMON_DATA;
 our $EDITIONS_DATA;
@@ -13,7 +13,7 @@ our $SRC_DATA;
 
 =head1 NAME
 
-HTML::Dojo - Provides the Dojo JavaScript / AJAX distribution 0.4.3 files.
+HTML::Dojo - Provides the Dojo AJAX distribution 0.3.0 files.
 
 =head1 SYNOPSIS
 
@@ -29,7 +29,7 @@ HTML::Dojo - Provides the Dojo JavaScript / AJAX distribution 0.4.3 files.
 
 =head1 DESCRIPTION
 
-HTML::Dojo provides files from the Dojo JavaScript / AJAX distribution.
+HTML::Dojo provides files from the Dojo JavaScript/AJAX distribution.
 
 These files include the C<dojo.js> file, the entire C<src> directory, 
 the C<iframe_history.html> file, various C<*.swf> files, the C<LICENSE>, 
@@ -101,17 +101,21 @@ The current editions available are:
 
 =item ajax
 
-=item charting
+=item browserio
 
-=item dojoWebsite
+=item core
+
+=item dashboard
 
 =item editor
 
+=item event
+
 =item event_and_io
 
 =item kitchen_sink
 
-=item lfx
+=item minimal
 
 =item moxie
 
@@ -119,8 +123,6 @@ The current editions available are:
 
 =item widget
 
-=item xdomain-ajax
-
 =over
 
 =cut
@@ -128,14 +130,17 @@ The current editions available are:
 sub editions {
     return qw/
         ajax
-        charting
+        browserio
+        core
+        dashboard
         editor
+        event
         event_and_io
         kitchen_sink
-        src
+        minimal
+        moxie
         storage
         widget
-        xdomain-ajax
     /;
 }
 
@@ -162,7 +167,7 @@ Optional arguments are:
 sub list {
     my ($self, $opt) = @_;
     
-    my $edition = $opt->{edition} || $self->{edition} || 'ajax';
+    my $edition = $opt->{edition} || $self->{edition} || 'core';
     $opt->{directories} = 0 if ! exists $opt->{directories};
     $opt->{files}       = 1 if ! exists $opt->{files};
     
@@ -221,7 +226,7 @@ Optional arguments are:
 
 =over
 
-=item C<edition>, default C<ajax>.
+=item C<edition>, default C<core>.
 
 =back
 
@@ -230,7 +235,7 @@ Optional arguments are:
 sub file {
     my ($self, $filename, $opt) = @_;
     
-    my $edition = $opt->{edition} || $self->{edition} || 'ajax';
+    my $edition = $opt->{edition} || $self->{edition} || 'core';
     
     croak "too many arguments, options must be a hash-ref" if @_ > 3;
     
