@@ -7,16 +7,21 @@ __CPAN_COMMON__ iframe_history.html
 
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
-	<title></title>
+	<title>The Dojo Toolkit</title>
 	<meta http-equiv="Content-Type" content="text/html; charset=utf-8"></meta>
 	<script type="text/javascript">
 	// <!--
 	var noInit = false;
 	var domain = "";
 	// document.domain = "localhost";
-	
-	function defineParams(sparams){
-		if(sparams){
+	function init(){
+		// parse the query string if there is one to try to get args that
+		// we can act on
+		var sparams = document.location.search;
+		if(sparams.length >= 0){
+			if(sparams.charAt(0) == "?"){
+				sparams = sparams.substring(1);
+			}
 			var ss = (sparams.indexOf("&amp;") >= 0) ? "&amp;" : "&";
 			sparams = sparams.split(ss);
 			for(var x=0; x<sparams.length; x++){
@@ -26,56 +31,17 @@ __CPAN_COMMON__ iframe_history.html
 				}
 			}
 		}
-	}
-	
-	function init(){
-		// parse the query string if there is one to try to get params that
-		// we can act on. Also allow params to be in a fragment identifier.
-		var query = null;
-		var frag = null;
-		var url = document.location.href;
-		var hashIndex = url.indexOf("#");
-		
-		//Extract fragment identifier
-		if(hashIndex != -1){
-			frag = url.substring(hashIndex + 1, url.length);
-			url = url.substring(0, hashIndex);
-		}
-
-		//Extract querystring
-		var parts = url.split("?");
-		if(parts.length == 2){
-			query = parts[1];
-		}
-
-		defineParams(query);
-		defineParams(frag);
 
 		if(noInit){ return; }
 		if(domain.length > 0){
 			document.domain = domain;
 		}
-		var hasParentDojo = false;
-		try{
-			hasParentDojo = window.parent != window && window.parent["dojo"];
-		}catch(e){
-			alert("Initializing iframe_history.html failed. If you are using a cross-domain Dojo build,"
-				+ " please save iframe_history.html to your domain and set djConfig.dojoIframeHistoryUrl"
-				+ " to the path on your domain to iframe_history.html");
-			throw e;
-		}
-
-		if(hasParentDojo){
-			//Set the page title so IE history shows up with a somewhat correct name.
-			document.title = window.parent.document.title;
-			
-			//Notify parent that we are loaded.
+		if((window.parent != window)&&(window.parent["dojo"])){
 			var pdj = window.parent.dojo;
 			if(pdj["undo"] && pdj["undo"]["browser"]){
 				pdj.undo.browser.iframeLoaded(null, window.location);
 			}
 		}
-
 	}
 	// -->
 	</script>
@@ -301,53 +267,34 @@ c!λ81Wt7 X5ZڠFךw:o濭ky'f==s7+bvfgW/%辏%!yI{qջCĘ^1G16 1Ӵu+Q9M[
 	lu<S8}mnD?RWgE6c&gCp]U?":&eHLr-5wt% {)2E|+Ky+liو5Ȳ	kc^#^f[M
 Yc=?
 __CPAN_COMMON__ Storage_version6.swf
-CWS  xڬXKo>$+q	cē8ddZ@:k& M-]L(R )'꦳]A7EWtٟЅ{ uyϹ}w};~eOKW&>qr}Ip
-go	Α>o½	owK<~`8Jv\?Dpw$^pCgnķ1Dl0CzĊx(
-GEa@7bnd*<؎
-ƴbiC#£F/$
-NFa&!8α}un˰^Ct7aM16Q|w=칉or/vqXCWg6y,Q:wv:OCpr{0'QfOb*qlG;SM0ppﻘXK&:PQKESkFGڤ,d	QbMwȩZV\jEQ+sTQ\jUQs0Kbw] ,#AO.[yr%}m~6t-
-} JuEů\=6C_򯷹Pzh_JyׄBt]R M\y!ɳQyq7:Sr7q88oΫ;S0YbtBd|6$=emG{)iB*7nqOqn%8.OլL9W,ƖOkxEx4˅~ ӮJ="乢W+k	R}!`^e+/2YfSBQ4ҫR:ӫY8Sz/D{@KN|PFpaĠ6a;R$FF2?K^Ou*ϥ¶':dk<3'e~}dU>V[t-ZCٲY>LbwOACh%zn8A;;)@a/tf7ހErVNuqp11@tf8^xp,9{vPFGO%(@L
-#E-tr_yN!=
-9F}
-C7Q-`鏂n⅁(@n;CBm(')~~A[|RrFnw>l{3aD|?;N>
-  R]zÛQR7C-"h	CmJ&gX&qEXд4IKV"X Ko.ܶoW2eN"Q4n0bq`ǡح"tLsͬoX
-'3_Z?r<VXK<m9e<7ZMi,lNW0 un#;571`K9c@~òQޟp̳)\N`ښ/Qَ@<P֮K9E"qʳ¡92u*9DJBڐT_H{|0O	V#ab
-E}^
-tC&V߮|)M]
-&ݜ5ԟuWA|IȪd|0]."{VlqyDW9r1:S	+BjOPM}[2brѻ]ٜ8,GA=-/,YB锄ԍp<)X͟@<䝲
-頖y,] TC# >nsEP|!Y,4\,K"!B&d$=;M(JtAPK$oZ6|em~vgyݴ 9[D/2N    'd
+CWS  xڜXrnHQ%
+Z)J,CvIEeB(# ׭0 !-vQ%E'ނ*rIS^ /ȁ*A==5?BP-qJ	.>qv{эpvZ]M^<?"]	xzObp}^d81D'An(-bn_4ׯqL| ^(Xen()>j7Gl08cQ 7}ы/	o ߍx}18&Izaߍ]x+;pl8x->y:Zҝz"jۅ>zmi8>HNGD/`NX|o#x.CDꁲif }Que{RApHf6c
+Y.PKZZJ-kjy)k*_Jhje)E+eY|lȯKDXCBeER{|^~U_
++NP܃4?\|zX
+KJ5#
+VR[o^@?AF<7[2t($Lݤy:y[a`='~s+ܝ88(Nli,svf
+M'3lt?E*%Ay49V,Хץ"|'vc-<wJ/;Y.TtZǒQ6(bΛ+^NK[@%h5J&i,Xx1XK"9?^,=){T,Yobux.td.˝%;I13qlU-[	ۓ ǣ<y̅g=0XA5ϾJް6W[
+w	y^gk0_ 	g@s"Q/\n
+} 9H
+wqΏ
+ᒠA7#p}Tv$ⓠ?5CD57<"BJ10k٭ܡRIghsyۮc7K&~/>e"7Eޝ*ІЌ1!fANlY+ys9d32dC<{.6`pJE*K7(YqD%S('ɓlAŨ]%5j
+
+ץ-XKPI>M%S鷉j&O%ʌ#l5k]\떆Ԗ2iOkhYx8ݕ=}Q|~"f+vJp.df;mfz~ƶGSU2v$ 3-,sMVq&8o^ůB-Q(ʾn>Jꨛ$*kI2̝⠳`v6(W\r<Wn	l&7T-UK{,LuW`bfېi]/'2#juSƢJw:D5;<MV9 'fP|FXʵ+қqIeZ|"JT:ԀkkMV&;ҔJ.CoJ⍻ifdm[+]km{qT~&|W\lerשV;JKz~p;_pRA9|<$>MɸTtqh$G)
+_p_~;/-a_~b$z4$Z9    k,
 __CPAN_COMMON__ Storage_version8.swf
-CWS   xڬn+8V8N$v1iv2BmɐhPJRvUvBhWbtS
-{IQ4Iz!{{P?@ Mr<_wzs[w}`zn_ӫ&MnsA*u=mhznM,
-,ݶ~g(zpu3w7=
-ipvޛUٺ	놱4Q͠jަWo5L'zrޅm=БEaJf]ө@&vc{Xl6vu4%5|R0G;h*(91#7=O?=-Ro6Sh9Y,;s|/e>]5-֡xSXmTD>)5mx
-˰7a%$Zq&7m[rn gá%l5,`s/m2?)4_$h͸
-mL)"U¬?L'
-LKMdIy
-*,U'1X)+oХN`~'1aL}tc0fb3ad>B§1r fENb*5\)+
-?^AKCr
-aAoZ<84ڕ+[ [kj3
-|)mdK&Ifsm̖
-zD5}Kvbd[Ƹ4Zr֜v]&W
-_q{)hIR9O1p' -Y4-8q*Z(0j	%vTT%ϕm(@gij/XS`6Ll54
-R.e(1'3@a0+aAck$zBX 4՞r-4f<O?p_Ûє.-ܚEC.*X=G*BѦ۳\>/FOsdCyi%.zB(/!.M^ty~^7K3QmL`DlL7>~<;#
-`"|WJ"sJfWbc7ze,F
-]_xNSr!c$
-X&  EGB/D0P^l
-]w-]vo}|}, POlC_=%zvZ;5^{FP}i3z}dX}aB
-\{Id 03rB)  ǀ=)({.I#AX7^H@dzLi|쇒MRͧVc_REV"FؑcGƎD|(8h|xf8Z<bcڡg# ^lSS݆{5_B}u\vUġdNcܲfwp9F	26
-.t4ojuqyŮ=hش ^8^§jS/7;ۃqt]Na;_x5ܪVq򛭭rYR\+udNI4<Д,ʧ~`6Hc:<uMO1]IDYY#D04E_x"{y:"OGij)liZ^-pgRVq' b%6L
-L)2A$j#Qעqp7y|d`DbesZ≠'hV4J{5W@Pf>mZbeQ6b]B!ly=t\ o@^5.  UҺXjOXJh"oDiܤ; \v3b{[A5 b z
-W#Bg
-;^1>m~(C VPk_HJ&y3ӂCpa}AG*slw['B4l泿{'ܼ[
-]QSËfq1[=q=Q!kv_v|b/_gEȯEv+Tߕx}{;q?$juxo۫S{i;#\Ai'56L].,VYmyVp
-=vP$#WmB^Ng}ە7,=kJj-XC:s;
-|͍7[:(f]
-z8Ѭc;WX]a
-S].&ՏuY`#)BʷWaujCePܝLa*h|Ty|` %Z
-/To>C=X0Ni8ZrÎ>t~!Қ*ũ(	M)V팠MtB0^Ų;}b?#߼hؽHJw 
-Ux[_I³,]*l]~%tҿ]\$oPpum-2M^,s%5Ӟ2_,%k\>^&wd4x
-MzU U8$POqJKN7bE/    s
+CWS  xڜXKsn 9[lZ˒mzuV2Hi*)U ` z[|-l*9s.jEP0=fA{:HKI;Hϋ{_^{7/uv}õu`cf(_aCyY
+9-h-LM2ky5<`{nY`F{Ӫvsǖ!U=z2`nh7
+vҶmQm~ۮg
+DdI~~d`9zݨCKFSh&Ws\-bfhYB^ꭖumn6Hv}z27m	Fͩs_^]n!ڞ4"ZY]XuXUXӛ[Sx8z6pxc,[ǴaR1iZ:U̟Hf @S3Pßah"Y1P%=MC9PXN@7#8*gJ.~U!C㟵b"bVLFVL~֊ȊZ1Y13p-K<[v0 I稨7
+PM^l<՚luHRwFZl,ٖL<f;XHĕGV疖&w
+rk$I{%hIr@~'&-Yin^r)Zh0w]4U)Nk6gXڧ;ZJ!ikD)0[tȶBzR+:ӼU^,i2-KKzBD 4ޙr[mVs8dr/hJa`\Nŗp_%Iʫ,w/Q{y {Z{;bz̍ep&{'O&7H&S*~]ɰ&b0.jL;>|d3<= 0jCeQcٕƍ镥,*$xLJoh|%s%s@rhRi<hw*{:<Oa[L;;lb'mCi_i[S=冊ͳh(롴'CiGlޓBM9Q%y}bz	}arrM%ٓIf<hiQ}g	}';.~ 9_A0 ;LFމsG@ 2tO¸
+6V=3\pPuǇk `i}4,\{j-p9[F9P9]^:zk|nu]u!1v-˹]&~g\P,l>@LNqP|5ҮZ7[[; җ\gpLY 	hI7?~tI§X}
+X1
+2uӨ_)IM
+%5=$
+f$53:"#ԸVN?&j글ޜSl0ݻ7(3?~)`cX<FuvM .]τRxCt}Ǳ#s n"YY衿6dr߈bJ1W8C{1ΥDL!"i+%V
+Vy;c	R:
+awB4&{w "qL拋rF`B (Gb>۸i%4R8\Qrhb0@zFHbŵ!P~aV(V<bbK<l#|PROSam	ۓỀ3q3Oh`hJȯ}K)I$Y^~-AVd^Dw#c_ Zy!L4}%[Tq|&k4yF>lۡFԖ9:V'*fS0~؅".,Iv7|̧w*Wh﷞C=ʷGyz[nAyy;R8/"b~S퍏[Ou-INͱ@밾Gʠ x:%Th5)I_PdťBiǯJ3q2;~22FMp2lcjʦؤ|,*ug	3rn"8b{vxVSs䄎eBFCͱ[<,Gp;ng.^.Ki-MlzIN/Ptg<<^T4}HWoBכf>7 :ÔS<=2ǂs    
 __CPAN_COMMON__ README
 The Dojo Toolkit
 ----------------
@@ -356,13 +303,14 @@ Dojo is a portable JavaScript toolkit for web application developers and
 JavaScript professionals. Dojo solves real-world problems by providing powerful
 abstractions and solid, tested implementations.
 
+
 Getting Started
 ---------------
 
 To use Dojo in your application, download one of the pre-built editions from the
-Dojo website, http://dojotoolkit.org. Once you have downloaded the file you will
-need to unzip the archive in your website root. At a minimum, you will need to
-extract:
+Dojo website, http://dojotoolkit.org. Once you have downloaded the file you
+will need to unzip the archive in your website root. At a minimum, you will
+need to extract:
 
     src/ (folder)
     dojo.js
@@ -373,11 +321,9 @@ To begin using dojo, include dojo in your pages by using:
     <script type="text/javascript" src="/path/to/dojo.js"></script>
 
 Depending on the edition that you have downloaded, this base dojo.js file may or
-may not include the modules you wish to use in your application. The files which
-have been "baked in" to the dojo.js that is part of your distribution are listed
-in the file build.txt that is part of the top-level directory that is created
-when you unpack the archive. To ensure modules you wish to use are available,
-use dojo.require() to request them. A very rich application might include:
+may not include the modules you wish to use in your application. To ensure that
+they are available, use dojo.require() to request them. A very rich application
+might include:
 
     <script type="text/javascript" src="/path/to/dojo.js"></script>
     <script type="text/javascript">
@@ -386,8 +332,8 @@ use dojo.require() to request them. A very rich application might include:
         dojo.require("dojo.storage.*");     // a persistent local data cache
         dojo.require("dojo.json");          // serialization to JSON
         dojo.require("dojo.dnd.*");         // drag-and-drop
-        dojo.require("dojo.lfx.*");         // animations and eye candy
-        dojo.require("dojo.widget.Editor2");// stable, portable HTML WYSIWYG
+        dojo.require("dojo.fx.*");          // animations and eye candy
+        dojo.require("dojo.widget.Editor"); // stable, portable HTML WYSIWYG
     </script>
 
 Note that only those modules which are *not* already "baked in" to dojo.js by
@@ -403,12 +349,12 @@ In addition to it's suite of unit-tests for core system components, Dojo has
 been tested on almost every modern browser, including:
 
     - IE 5.5+
-    - Mozilla 1.5+, Firefox 1.0+
+    - Mozilla 1.2+, Firefox 1.0+
     - Safari 1.3.9+
     - Konqueror 3.4+
     - Opera 8.5+
 
-Note that some widgets and features may not perform exactly the same on every
+Note that some widgets and features may not preform exactly the same on every
 browser due to browser implementation differences.
 
 For those looking to use Dojo in non-browser environments, please see "Working
@@ -451,7 +397,7 @@ problems. You're most likely to find them at:
 
     irc.freenode.net #dojo
 
-Note that 3PM Wed PST in #dojo-meeting is reserved for a weekly meeting between
+Note that 2PM Wed PST in this channel is reserved for a weekly meeting between
 project developers, although anyone is welcome to participate.
 
 
@@ -471,7 +417,7 @@ repository are available at:
 
 Anonymous Subversion access is also available:
 
-    %> svn co http://svn.dojotoolkit.org/dojo/trunk/ dojo
+    %> svn co http://dojootoolkit.org/svn/dojo/trunk/
 
 Each of these sources will include some extra directories not included in the
 pre-packaged editions, including command-line tests and build tools for
@@ -519,10 +465,10 @@ could then make a profile build using it by doing:
     %> ant -Dprofile=test -Ddocless=true release intern-strings
 
 If the build is successful, your newly minted and compressed  profile build will
-be placed in [dojo]/release/dojo/
+be placed in [dojo]/releae/dojo/
 
 -------------------------------------------------------------------------------
-Copyright (c) 2004-2006, The Dojo Foundation, All Rights Reserved
+Copyright (c) 2004-2005, The Dojo Foundation, All Rights Reserved
 
 vim:ts=4:et:tw=80:shiftwidth=4:
 
@@ -542,20 +488,20 @@ The text of the AFL and BSD licenses is reproduced below.
 The "New" BSD License:
 **********************
 
-Copyright (c) 2005-2006, The Dojo Foundation
+Copyright (c) 2005, The Dojo Foundation
 All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
 
   * Redistributions of source code must retain the above copyright notice, this
-    list of conditions and the following disclaimer.
+	list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
+	this list of conditions and the following disclaimer in the documentation
+	and/or other materials provided with the distribution.
   * Neither the name of the Dojo Foundation nor the names of its contributors
-    may be used to endorse or promote products derived from this software
-    without specific prior written permission.
+	may be used to endorse or promote products derived from this software
+	without specific prior written permission.
 
 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
